@@ -161,7 +161,8 @@ restart :
 	    continue ;  
 	  case '/':		/* // means start of comment */
 	    if ((ch = _FREECHAR) == '/')
-	      { while ((ch = _FREECHAR) != '\n' && ch != (unsigned char)EOF) ;
+	      {
+		while ((ch = _FREECHAR) != '\n' && ch != (unsigned char)EOF) {}
 		goto got_line ;
 	      }
 	    else
@@ -269,7 +270,8 @@ BOOL freeread (FILE *fil)                /* reads card from fil */
 	  goto got_line ;
 	case '/' :		/* // means start of comment */
 	  if ((ch = getc (fil)) == '/')
-	    { while (getc(fil) != '\n' && !feof(fil)) ;
+	    {
+	      while (getc(fil) != '\n' && !feof(fil)) {}
 	      ++*line ;
 	      if (in > card)	/* // at start of line ignores line */
 		goto got_line ;
