@@ -354,7 +354,7 @@ void messcrash (char *format,...)
       (*vr)() ;			/* call user cleanup routine */
     }
 
-  abort() ;
+  exit(1);
 }
 
 /*****************************/
