@@ -1,4 +1,4 @@
-/* $Id: caf2gap.c 20877 2007-06-08 08:59:00Z rmd $ */
+/* $Id: caf2gap.c 36373 2013-11-20 12:01:41Z aw7 $ */
 /*
  * This software has been created by Genome Research Limited (GRL). 
  * GRL hereby grants permission to use, copy, modify and distribute 
@@ -55,7 +55,7 @@ static void write_2_swapped(FILE *f, void *a, int len)
   int i;
   static Array buf;
   if (buf == NULL) buf = arrayCreate(BLOCKSIZE, uint_2);
-  array(buf, len, uint_2);	/* force resize */
+  arrayp(buf, len, uint_2);	/* force resize */
   for(i=0;i<len;i++) {
     swap_int2(((uint_2 *)a)[i],arr(buf,i,uint_2));
   }
@@ -67,7 +67,7 @@ static void write_4_swapped(FILE *f, void *a, int len)
   int i;
   static Array buf = NULL;
   if (buf == NULL) buf = arrayCreate(BLOCKSIZE,uint_4);
-  array(buf,len,uint_4);	/* force resize */
+  arrayp(buf,len,uint_4);	/* force resize */
   for(i=0;i<len;i++) {
     swap_int4(((uint_4 *)a)[i],arr(buf,i,uint_4));
   }
@@ -80,7 +80,7 @@ static void write_N_swapped(FILE *f, void *a, int len, int N)
   int j;
   static Array buf = NULL;
   if (buf == NULL) buf = arrayCreate(BLOCKSIZE,char);
-  array(buf,len*N,char);	/* force resize */
+  arrayp(buf,len*N,char);	/* force resize */
   for(i=0;i<len;i++) {
     for(j=0;j<N;j++) {
       arr(buf,i*N+j,char) = ((char *)a)[i*N+(N-j-1)];
@@ -178,8 +178,8 @@ static void set_writes(void)
 static void open_gap_db_write(char *project, char *version, int force,
 			      Gap_db *gap_db)
 {
-  char image[MAX_FILENAME_LEN];    /* Name of image file */
-  char aux[MAX_FILENAME_LEN];      /* Name of aux file   */
+  char image[MAX_FILENAME_LEN * 2 + 2];    /* Name of image file */
+  char aux[MAX_FILENAME_LEN * 2 + 6];      /* Name of aux file   */
   char *s;
   
   int oflag;           /* File permissions */
@@ -207,8 +207,8 @@ static void open_gap_db_write(char *project, char *version, int force,
   for(s=project;*s;s++) *s = toupper((int)*s);
   for(s=version;*s;s++) *s = toupper((int)*s);
   
-  sprintf(image, "%s.%s",     project, version);
-  sprintf(aux,   "%s.%s.aux", project, version);
+  snprintf(image, sizeof(image), "%s.%s",     project, version);
+  snprintf(aux,   sizeof(aux),   "%s.%s.aux", project, version);
 
 #ifndef S_DEFFILEMODE
 #define S_DEFFILEMODE   (S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH)
@@ -254,7 +254,7 @@ static char * zeros(int N)
   if(buf==NULL) {
     buf = arrayCreate(BLOCKSIZE,char);
   }
-  array(buf, N, char);
+  arrayp(buf, N, char);
   return arrp(buf, 0, char);
 }
 
@@ -311,7 +311,7 @@ static GCardinal write_record(Gap_db * gap_db,
   
   used = size * number + sizeof(GCardinal); /*4 is for type*/
 
-  array(gap_db->records, record, AuxIndex); /* force resize */
+  arrayp(gap_db->records, record, AuxIndex); /* force resize */
   arr(  gap_db->records, record, AuxIndex).image[0] = gap_db->image_count;
   arr(  gap_db->records, record, AuxIndex).time[0]  = STARTDATE;
   arr(  gap_db->records, record, AuxIndex).used[0]  = used;
@@ -384,9 +384,7 @@ static void write_index(Gap_db *gap_db)
   /*************************************************************
    * Header
    *************************************************************/
-  if (gap_db->image_count > 1879048192 /* 1792 MiB */) {
-    gap_db->flags |= AUX_64_BIT_MODE;
-  }
+  gap_db->flags |= AUX_64_BIT_MODE; /* always on now */
   header.file_size   = gap_db->image_count;
   header.block_size  = BLOCKSIZE;
   header.num_records = gap_db->num_records;
@@ -447,12 +445,12 @@ static void check_caf_consistency(cafAssembly *caf, Array contig_ids,
     /* 
      */
     stbl = arrayCreate(num_readings, int);
-    array(stbl, num_readings, int); /* Force resize */
+    arrayp(stbl, num_readings, int); /* Force resize */
 
     seqs = caf->seqs;
 
     ftbl = arrayCreate(arrayMax(seqs), int);
-    array(ftbl, arrayMax(seqs), int); /* Force resize */
+    arrayp(ftbl, arrayMax(seqs), int); /* Force resize */
 
     /* Scan for all sequences that have type 'is_read' */
 
@@ -600,13 +598,10 @@ static void count_caf_items(cafAssembly *caf,
 
         CAFSEQ *contig_seq;
         int    j, contig_id;
-        char   *contig_name;
 
         contig_id = arr(contig_ids, i, int);
         contig_seq = arrp(seqs, contig_id, CAFSEQ);
 
-        contig_name = dictName(caf->seqDict, contig_seq->id);
-
         /*
          * Because we only stored contigs that contained reads we dont need
          * to check again.
@@ -683,17 +678,19 @@ static void get_contig_seqids(cafAssembly *caf, Array contig_ids,
   CAFSEQ *seq;
   int i = 0;
   int j = 0;
-
+  
   array(contig_ids, num_contigs, int) = 0; /* Force resize */
 
   seqs = caf->seqs;
   for (i = 0; i < arrayMax(seqs); i++) {
     seq = arrp(seqs, i, CAFSEQ);
     if (seq->type == is_contig) {
-      arr(contig_ids, j, int) = i;
-      j++;
+    	if(seq->assinf && arrayMax(seq->assinf) > 0) { // ignore empty contigs
+      	    arr(contig_ids, j, int) = i;
+      	    j++;
+	}
     }
-  }  
+  }
 }
 
 static int af_compare(const void *a, const void *b)
@@ -705,7 +702,7 @@ static int af_compare(const void *a, const void *b)
 
   mina = min(aa->s1, aa->s2);
   minb = min(bb->s1, bb->s2);
-
+  
   return (mina - minb);
 }
 
@@ -716,7 +713,7 @@ void sort_assembled_from(cafAssembly *caf, Array contig_ids, int num_contigs)
   ASSINF *assembled_froms;
   int i = 0;
   int contig_id;
-
+  
   seqs = caf->seqs;
   for (i = 0; i < num_contigs; i++) {
     contig_id = arr(contig_ids, i, int);
@@ -745,28 +742,27 @@ void assign_staden_ids(cafAssembly *caf, Array contig_ids, int num_contigs,
 {
   Array  seqs;
   CAFSEQ *contig_seq;
-  DICT   *seq_dict;
   ASSINF *af;
   int i, j;
   int contig_id;
   int read_id;
 
   seqs = caf->seqs;
-  seq_dict = caf->seqDict;
   array(Readings->obj_num, arrayMax(seqs), int) = 0; /* Force resize */
   
   for (i = 0; i < num_contigs; i++) {
     contig_id = arr(contig_ids, i, int);
     contig_seq = arrp(seqs, contig_id, CAFSEQ);
     if (!contig_seq->assinf) continue;
-
+    
     for (j = 0; j < arrayMax(contig_seq->assinf); j++) {
       af = arrp(contig_seq->assinf, j, ASSINF);
       read_id = af->seq;
+      
       if (arr(Readings->obj_num, read_id, int) != 0) {
 	continue;
       }
-
+      
       arr(Readings->obj_num, read_id, int) = ++Readings->curr_id;
     }
   }
@@ -867,7 +863,7 @@ static void sanitise_staden_ids(cafAssembly *caf, Array contig_ids,
     int      excess_sid = 0, negative_sid = 0, zero_sid = 0, valid_sid = 0;
     int      duplicate_sid = 0, max_sid;
     int      num_ref_reads = 0;
-
+    
     seqs = caf->seqs;
 
     /*
@@ -882,7 +878,7 @@ static void sanitise_staden_ids(cafAssembly *caf, Array contig_ids,
      * the correct size but subtract 1 from staden id's when indexing.
      */
     stbl = arrayCreate(num_readings, Staden_id_map);
-    array(stbl, num_readings, Staden_id_map); /* Force resize */
+    arrayp(stbl, num_readings, Staden_id_map); /* Force resize */
 
     /*
      * table of read identifiers (in the CAF sense, not the staden sense)
@@ -899,7 +895,7 @@ static void sanitise_staden_ids(cafAssembly *caf, Array contig_ids,
     free_tbl.data = arrayCreate(0, int); 
 
     max_sid = num_readings; /* Should never see a staden id > than this */
-
+    
     for(i = 0; i < num_contigs; i++) {
 
         CAFSEQ *contig_seq;
@@ -1208,7 +1204,7 @@ static int write_sequence(Gap_db *gap_db, Stack dna_stack, int read_sense,
        if we try to make a bigger one */
     buf = arrayCreate(30000, char);
   }
-  array(buf, len, char);
+  arrayp(buf, len, char);
   converted_dna = arrp(buf, 0, char);
 
   strncpy(converted_dna, dna, len);
@@ -1285,7 +1281,7 @@ static int write_positions(Gap_db *gap_db, Array assinf, int read_sense,
        if we try to make a bigger one */
     buf = arrayCreate(30000, int2);
   }
-  array(buf, len, int2);
+  arrayp(buf, len, int2);
   positions = arrp(buf, 0, int2);
   
   align_to_scf = arrp(assinf, 0, ASSINF);
@@ -1353,7 +1349,7 @@ static int write_positions_pads(Gap_db *gap_db, Stack dna_stack,
 	    "Warning: A read with no Align_to_SCF record has been found.\n"
 	    "Some traces may not align correctly to the corresponding reads\n");
   }
-  array(buf, len, int2);
+  arrayp(buf, len, int2);
   positions = arrp(buf, 0, int2);
 
   dna = stackText(dna_stack, 0);
@@ -1417,7 +1413,7 @@ static GCardinal char2type(char *s)
   unsigned char t[sizeof(GCardinal)];
   int len = min(strlen(s), sizeof(GCardinal));
 
-  strncpy((char *)&t[0],s,len);
+  memcpy(&t[0],s,len);
   if (len < sizeof(GCardinal)) memset(&t[len],' ',sizeof(GCardinal) - len);
 
   return (t[0]<<24) + (t[1]<<16) + (t[2]<<8) + (t[3]<<0);
@@ -1479,10 +1475,10 @@ static void add_tags(Gap_db *gap_db, cafAssembly *caf, Array annotations,
 	if (!new_comment) {
 	  new_comment = arrayCreate(1000, char);
 	}
-	array(new_comment,
-	      (strlen(tag_type)
-	       + (tag_comment ? strlen(tag_comment) : 0)
-	       + 14),
+	arrayp(new_comment,
+	       (strlen(tag_type)
+		+ (tag_comment ? strlen(tag_comment) : 0)
+		+ 14),
 	       char);
 	sprintf(arrp(new_comment, 0, char),
 		"CAF:Method=%s::%s", tag_type, tag_comment ? tag_comment : "");
@@ -2044,7 +2040,7 @@ static BMAP_BASE_TYPE *bits(int N)
     rem   = N % BMAP_BITS_PER_ELEMENT;
 
     if (buf == NULL) buf = arrayCreate(whole + 1, BMAP_BASE_TYPE);
-    array(buf, whole, BMAP_BASE_TYPE);	/* force resize */
+    arrayp(buf, whole, BMAP_BASE_TYPE);	/* force resize */
 
     memset(arrp(buf, 0, BMAP_BASE_TYPE), '\377', whole * BMAP_ELEMENT_SIZE);
     if (rem) arr(buf, whole, BMAP_BASE_TYPE) = (1 << rem) - 1;
@@ -2281,7 +2277,7 @@ int main(int argc, char** argv)
   open_gap_db_write(project, version, force, &gap_db);
 
   CAF = readCafAssembly(fp, acefile, NULL);
-
+  
   caf2gap(CAF, silent, preserve, db_version, &gap_db);
 
   close_gap_db(&gap_db);
