@@ -552,7 +552,7 @@ void get_description(cafAssembly *CAF, CAFSEQ * seq, char * description)
   if (seq->dye) chem = (seq->dye == dye_terminator) ? "term" : "prim";
   if (seq->template_id) templ = dictName(CAF->templateDict,seq->template_id);
 
-  if (strncpy(name_copy, name, 256))
+  if (snprintf(name_copy, sizeof(name_copy), "%s", name) < sizeof(name_copy))
     get_read_info_from_name(name_copy, &strand, &chem, &dye, &templ);
   
   if (!strand) strand = "fwd";
