@@ -156,7 +156,7 @@ contigAlignment
   alignData *ad;
   double *q, *Q;
   int pos;
-  int is_s1;
+  /* int is_s1; */
   STORE_HANDLE handle;
   int tot = 0;
 
@@ -322,10 +322,12 @@ contigAlignment
 	  if ( s1_only ) /* this code is highly dodgy and only used for debugging ! */
 	    {
 	      if ( (dot = strchr( dictName(seqDict,a->seq), '.' )) && !strcmp(dot,".s1") )
-		is_s1 = TRUE;
+		{
+		/* is_s1 = TRUE; */
+		}
 	      else
 		{
-		  is_s1 = FALSE;
+		  /* is_s1 = FALSE; */
 		  seq->bad = TRUE;
 		}
 	    } 
@@ -619,7 +621,7 @@ compare_edits_to_consensus( cafAssembly *CAF, contigAlignment *Align, FILE *fp,
   alignStatus *S;
   Array status = Align->status;
   Array dna = Align->cons; 
-  Array quality;
+  /* Array quality; */
   
   int same[status_count][Consensus_count];
   int different[status_count][Consensus_count];
@@ -644,7 +646,7 @@ compare_edits_to_consensus( cafAssembly *CAF, contigAlignment *Align, FILE *fp,
   if ( fp )
     fprintf(fp, "from: %d to: %d\n\n", min, max );
 
-  quality = arrayHandleCreate( Align->max+1, traceQuality, Align->handle);
+  /* quality = arrayHandleCreate( Align->max+1, traceQuality, Align->handle); */
 
   for(j=min;j<=max;j++)
     {
