@@ -15,7 +15,7 @@
  * Our software can be freely distributed under the conditions set 
  * out above, and must contain this copyright notice.
  *
- * $Id: cafseq.c 15228 2005-06-21 15:46:26Z rmd $
+ * $Id: cafseq.c 25667 2008-06-03 09:46:23Z rmd $
  * $Log$
  * Revision 1.17  2005/06/21 15:46:26  rmd
  * Use <> in #include lines instead of "".
@@ -87,6 +87,8 @@
  */
 
 #include <time.h>
+#include <stdint.h>
+#include <inttypes.h>
 #include <caf.h>    /* CAF definitions */
 #include <cafseq.h> /* internal IO functions */
 #include <cl.h>     /* Command-line parsing */
@@ -859,12 +861,12 @@ writeNotes(Array notes, DICT *noteTypeDict, char *note_name, FILE *fil)
 		       dictName(noteTypeDict, note1->type),
 		       note1->ctime, note1->mtime);
 #elif SIZEOF_TIME_T == 8
-	      fprintf (fil, "%s %s %ld %ld", note_name, 
+	      fprintf (fil, "%s %s %"PRIu64"d %"PRIu64"d", note_name, 
 		       dictName(noteTypeDict, note1->type),
-		       (((long) note1->ctime_top << 32)
-			+ ((unsigned long)note1->ctime) & 0xFFFFFFFF),
-		       (((long) note1->mtime_top << 32)
-			+ ((unsigned long)note1->mtime) & 0xFFFFFFFF));
+		       (((uint64_t) note1->ctime_top << 32)
+			+ (((unsigned long)note1->ctime) & 0xFFFFFFFF)),
+		       (((uint64_t) note1->mtime_top << 32)
+			+ (((unsigned long)note1->mtime) & 0xFFFFFFFF)));
 #else
 #error Unsupported time_t size: SIZEOF_TIME_T in (writeNotes())
 #endif
@@ -904,7 +906,7 @@ itoa_cache( int i )
     }
 }
 
-#define MAX_QUAL_VAL 99
+#define MAX_QUAL_VAL 100
 
 int  
 write_base_quality( Array base_quality, FILE *fil )
@@ -1786,12 +1788,12 @@ int
 rawdata(int argc, char **argv)
 /* check the command line for the RAWDATA environment variable (for SCF files) */
 {
-  static char rawdata[256];
+  static char rawdata[266];
   char arg[256];
 
   if ( getarg("-rawdata",arg,argc,argv) )
     {
-      sprintf( rawdata, "RAWDATA=%s", arg );
+      snprintf( rawdata, sizeof(rawdata), "RAWDATA=%s", arg );
       putenv( rawdata );
       return 1;
     }
