@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+#include <time.h>
 
 #include <cl.h>
 
@@ -638,7 +639,8 @@ file_date( char *filename )
 {
   FILE *fp;
   struct stat buf;
-  char date[256], *t;
+  static char date[256];
+  char *t;
 
   strcpy( date, "?");
 
@@ -648,18 +650,14 @@ file_date( char *filename )
       if ( ! stat( filename, &buf ) )
 	{
 	  sprintf( date, "%s", ctime(&buf.st_mtime) );
-	  t = date;
-	  while ( *t )
+	  t = strchr(date, '\n');
+	  if ( t )
 	    {
-	      if ( *t == '\n')
-		*t = 0;
-	      t++;
+	      *t = 0;
 	    }
-
 	}
     }
-  t = date;
-  return t;
+  return date;
 }
 
 typedef struct use_list
