@@ -169,10 +169,10 @@ if the flag extend==FALSE then the reads are not extended out again, which may r
   int problems, previous;
   CLIP *problem;
   DEPTH *d, *clipped_d;
-  qual_struct *qs;
+  /* qual_struct *qs; */
   int s1c, s2c;
   int clip_left_at, clip_right_at;
-  char *dna;
+  /* char *dna; */
   Array orig_consensus=Align->cons;
   int max_score, strand, readslot;
   float lax_len=0, strict_len=0, total=0;
@@ -183,7 +183,7 @@ if the flag extend==FALSE then the reads are not extended out again, which may r
 
   covered = arrayCreate(max+1,int);
   coverage = arrayCreate(max+1,DEPTH);
-  array(coverage,max,DEPTH);
+  arrayp(coverage,max,DEPTH);
   clipped_coverage = arrayCreate(max+1,DEPTH);
   arrayp(clipped_coverage,max,DEPTH);
   read_quality = arrayCreate(1000,qual_struct);
@@ -204,7 +204,7 @@ arrayMax(contig->assinf), min, max ); */
 	debugging = ! strcmp(dictName(CAF->seqDict,lax->seq),debug_read ); /* debug on this reading */
 
       seq = arrp(seqs,lax->seq,CAFSEQ);
-      dna = stackText(seq->dna,0)-1;
+      /* dna = stackText(seq->dna,0)-1; */
 
       /* strict is an array which will eventually hold the clipped
          assembled_from info. Initially it is just a copy of the
@@ -729,17 +729,18 @@ arrayMax(contig->assinf), min, max ); */
 
   if ( logf )
     fprintf(logf,"\nmean lax clip length: %.1f\nmean strict clip length: %.1f\n", lax_len/total, strict_len/total );
-	  
+#if 0	  
   for(i=0;i<arrayMax(read_quality);i++)
     {
       qs = arrp(read_quality,i,qual_struct);
-/*      if ( qs->edit )
+      if ( qs->edit )
 	arrayDestroy(qs->edit );
       if ( qs->Left)
 	arrayDestroy(qs->Left);
       if ( qs->Right )
-	arrayDestroy(qs->Right); */
+	arrayDestroy(qs->Right);
     }
+#endif
   arrayDestroy(read_quality); 
   arrayDestroy(problem_interval); 
   arrayDestroy(coverage); 
@@ -796,9 +797,9 @@ rescore_alignment( CAFSEQ *read, ASSINF *lax, contigAlignment *Align, int origin
 
 */
   int max_score;
-  int score, l, start_r, start_s, j;
+  int score, l, start_r, /* start_s, */ j;
   Array *B;
-  int s1c, s2c, readslot;
+  int /* s1c, s2c, */ readslot;
   alignData *ad;
   int s1, s2;
   int s;
@@ -829,11 +830,11 @@ rescore_alignment( CAFSEQ *read, ASSINF *lax, contigAlignment *Align, int origin
   ad = arrp( *B, readslot, alignData );
   
   max_score = -1;
-  s1c = s1;
+  /* s1c = s1; */
   score = 0;
   l = ad->pos;
   start_r = l;
-  start_s = s1;
+  /* start_s = s1; */
   
   *lax_score = *strict_score = 0;
   
@@ -863,14 +864,14 @@ rescore_alignment( CAFSEQ *read, ASSINF *lax, contigAlignment *Align, int origin
 	    start_r = l+1;
 	  else
 	    start_r = l-1;
-	  start_s = j+1;
+	  /* start_s = j+1; */
 	}
       else if ( score > max_score )
 	{
 	  *clip_right_at = l;
-	  s2c = j;
+	  /* s2c = j; */
 	  *clip_left_at = start_r;
-	  s1c = start_s;
+	  /* s1c = start_s; */
 	  max_score = score;
 	  *strict_score = score;
 	}
