@@ -98,7 +98,7 @@ non_recursive_est_to_genome( SEQUENCE *est, SEQUENCE *genome, int match, int mis
   int *temp_path = 0;
   int is_acceptor;
   ge_alignment *ge = (ge_alignment*)calloc(1,sizeof(ge_alignment));
-  coords *start1 = 0, *start2 = 0, *t1 = 0, *t2 = 0, *t3 = 0, *best_intron_start = 0, best_start;
+  coords *start1 = 0, *start2 = 0, *t1 = 0, *t2 = 0, *t3 = 0, *best_intron_start = 0, best_start = { 0 };
   int splice_type = 0;
 
   unsigned char direction;
