@@ -588,8 +588,8 @@ pad_reading( CAFSEQ *seq, cafAssembly *CAF, int reversed, int R1, int R2, int S1
       S2 = r;
     }
 
-  array(rc_mapping,R2,int);
-  array(r_pads,R2,int);
+  arrayp(rc_mapping,R2,int);
+  arrayp(r_pads,R2,int);
   for(r=R1;r<=R2;r++)	/* create the mapping of the unpadded read to the unpadded contig */
     {
       s = arr(rc_mapping,r,int);
@@ -1085,7 +1085,7 @@ depad_seq( char *seq )
       if ( *s != padding_char )
 	*t++ = *s++;
       else
-	*s++;
+	s++;
     }
   *t = 0;
   
