@@ -172,9 +172,11 @@ char * embl_seq_comment(SEQUENCE *seq, char *key)
 
 char * nbrf_seq_comment(SEQUENCE *seq, char *key)
 {
+#if 0
   char line[256];
   unsigned long text_offset;
   unsigned long end_pos;
+#endif
   static char buf[MAX_BUF];
 
   *buf = 0;
@@ -477,7 +479,6 @@ SEQUENCE * get_fasta_sq(FILE *fp)
   int c;
   SEQUENCE *seq=NULL;
   char name[256], desc[256];
-  char *s;
   int i;
   static char *buffer=NULL;
   static int buflen=0;
@@ -533,7 +534,7 @@ SEQUENCE * get_fasta_sq(FILE *fp)
 
       buffer[seq->len] = 0;
 
-      s = seq->s = (char*)strdup(buffer);
+      seq->s = (char*)strdup(buffer);
       
       buffer[0] = 0;
 
