@@ -68,7 +68,7 @@ main( int argc, char **argv )
   size_t s1, s2;
   WORD_DICT *dictionary;
   SEQUENCE *seq;
-  char db[256], bufferfile[256], bufferfile2[256], bufferfile3[256], outfile[256], triple_file[256];
+  char db[256], bufferfile[270], bufferfile2[550], bufferfile3[550], outfile[256], triple_file[270];
   HP *pbuffer, p1, p2, *list;
   HT *tbuffer, triple;
   FILE  *bfp, *obfp, *bfp1, *bfp2, *outfp, *fasta;
@@ -79,7 +79,6 @@ main( int argc, char **argv )
   int written=0, wmax=0;
   int files, list_index, threshold, pthresh=1;
   char **name;
-  int dumps;
   int list_size_threshold=-1;
   FILE *freqfp;
   char freqfile[256];
@@ -88,7 +87,7 @@ main( int argc, char **argv )
   int *ignore;
   int ignored=0;
   int total=0;
-  char tmpdir[256], mergefile[256];
+  char tmpdir[256], mergefile[270];
   
 /* command line parsing and initialisation */
 
@@ -398,7 +397,6 @@ main( int argc, char **argv )
       wcount = (int*)calloc(2*DBMAX,sizeof(int));
       
       threshold = 0.9*tmax_buf;
-      dumps = 0;
 
       /* read in the HP pairs, sorted by word */
 
